==> qiho-center-api-2.6.2-hrd-20200824.023258-5-sources.jar: com/qiho/center/api/params/OrderStrategyParams.java <==
package com.qiho.center.api.params;

import java.util.Date;
import java.util.List;

/**
 * Created by danke on 2017/6/22.
 */
public class OrderStrategyParams extends PageQueryParams{

    /**
     * 策略id
     */
    private Long id;
    /**
     * 策略名称
     */
    private String strategyName;

    /**
     * 策略类型
     */
    private Integer strategyType;
    /**
     * 创建人
     */
    private String creator;
    /**
     * 创建时间
     */
    private Date gmtCreate;
    /**
     * 更新人
     */
    private String updator;
    /**
     * 更新时间
     */
    private Date gmtModified;

    /**
     * 策略状态
     * @return
     */
    private Integer status;

    private Integer useType;

    private List<Long> idList;

    public Integer getUseType() {
        return useType;
    }

    public void setUseType(Integer useType) {
        this.useType = useType;
    }

    public List<Long> getIdList() {
        return idList;
    }

    public void setIdList(List<Long> idList) {
        this.idList = idList;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getCreator() {
        return creator;
    }

    public void setCreator(String creator) {
        this.creator = creator;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public String getUpdator() {
        return updator;
    }

    public void setUpdator(String updator) {
        this.updator = updator;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public String getStrategyName() {
        return strategyName;
    }

    public void setStrategyName(String strategyName) {
        this.strategyName = strategyName;
    }

    public Integer getStrategyType() {
        return strategyType;
    }

    public void setStrategyType(Integer strategyType) {
        this.strategyType = strategyType;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }
}

==> qiho-center-api-2.7.24-hrd-20201211.063546-2-sources.jar: com/qiho/center/api/params/OrderStrategyParams.java <==
package com.qiho.center.api.params;

import java.util.Date;
import java.util.List;

/**
 * Created by danke on 2017/6/22.
 */
public class OrderStrategyParams extends PageQueryParams{

    /**
     * 策略id
     */
    private Long id;
    /**
     * 策略名称
     */
    private String strategyName;

    /**
     * 策略类型
     */
    private Integer strategyType;
    /**
     * 创建人
     */
    private String creator;
    /**
     * 创建时间
     */
    private Date gmtCreate;
    /**
     * 更新人
     */
    private String updator;
    /**
     * 更新时间
     */
    private Date gmtModified;

    /**
     * 策略状态
     * @return
     */
    private Integer status;

    private Integer useType;

    private List<Long> idList;


    private Integer accessType;

    public Integer getAccessType() {
        return accessType;
    }

    public void setAccessType(Integer accessType) {
        this.accessType = accessType;
    }

    public Integer getUseType() {
        return useType;
    }

    public void setUseType(Integer useType) {
        this.useType = useType;
    }

    public List<Long> getIdList() {
        return idList;
    }

    public void setIdList(List<Long> idList) {
        this.idList = idList;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getCreator() {
        return creator;
    }

    public void setCreator(String creator) {
        this.creator = creator;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public String getUpdator() {
        return updator;
    }

    public void setUpdator(String updator) {
        this.updator = updator;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public String getStrategyName() {
        return strategyName;
    }

    public void setStrategyName(String strategyName) {
        this.strategyName = strategyName;
    }

    public Integer getStrategyType() {
        return strategyType;
    }

    public void setStrategyType(Integer strategyType) {
        this.strategyType = strategyType;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }
}
